==> DQScriptsDemo_0_2_1.zip: DQScriptsDemo_0_2_1/rgss-lib/dq/title/rgss/Scene_Title_main.rb <==
#==============================================================================
#  Scene_Title#main
#------------------------------------------------------------------------------
# cpp^Cgʂ̏sNXłB
# Copyright (C) 2005 fukuyama
#==============================================================================

class Scene_Title
  #--------------------------------------------------------------------------
  #  C
  #--------------------------------------------------------------------------
  def main
    # 퓬eXg̏ꍇ
    if $BTEST
      battle_test
      return
    end
    # f[^x[X[h
    $data_actors        = load_data("Data/Actors.rxdata")
    $data_classes       = load_data("Data/Classes.rxdata")
    $data_skills        = load_data("Data/Skills.rxdata")
    $data_items         = load_data("Data/Items.rxdata")
    $data_weapons       = load_data("Data/Weapons.rxdata")
    $data_armors        = load_data("Data/Armors.rxdata")
    $data_enemies       = load_data("Data/Enemies.rxdata")
    $data_troops        = load_data("Data/Troops.rxdata")
    $data_states        = load_data("Data/States.rxdata")
    $data_animations    = load_data("Data/Animations.rxdata")
    $data_tilesets      = load_data("Data/Tilesets.rxdata")
    $data_common_events = load_data("Data/CommonEvents.rxdata")
    $data_system        = load_data("Data/System.rxdata")
    Properties_Interface_Module.load_properties($data_states,'id','Data/ActionLogStates.rxdata')
    Properties_Interface_Module.load_properties($data_skills,'id','Data/ActionLogSkills.rxdata')
    Properties_Interface_Module.load_properties($data_items,'id','Data/ActionLogItems.rxdata')
    # VXeIuWFNg쐬
    $game_system = Game_System.new
    # ^CgOtBbN쐬
    @sprite = Sprite.new
    @sprite.bitmap = RPG::Cache.title($data_system.title_name)
    # ^Cg BGM t
    $game_system.bgm_play($data_system.title_bgm)
    # MEABGS ̉t~
    Audio.me_stop
    Audio.bgs_stop
    # gWVs
    Graphics.transition(8)
    # C[v
    loop do
      # Q[ʂXV
      Graphics.update
      # ͏XV
      Input.update
      # t[XV
      update
      # ʂ؂ւ烋[v𒆒f
      if $scene != self
        break
      end
    end
    # gWV
    Graphics.freeze
    # ^CgOtBbN
    @sprite.bitmap.dispose
    @sprite.dispose
  end
  #--------------------------------------------------------------------------
  #  t[XV
  #--------------------------------------------------------------------------
  def update
    # C {^ꂽꍇ
    if Input.trigger?(Input::C)
      $scene = DQ::Scene_Title.new
    end
  end
end

==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/title/rgss/Scene_Title_main.rb <==
#==============================================================================
#  Scene_Title#main
#------------------------------------------------------------------------------
# cpp^Cgʂ̏sNXłB
# Copyright (C) 2005 fukuyama
#==============================================================================

class Scene_Title
  #--------------------------------------------------------------------------
  #  C
  #--------------------------------------------------------------------------
  def main
    # 퓬eXg̏ꍇ
    if $BTEST
      battle_test
      return
    end
    # f[^x[X[h
    $data_actors        = load_data("Data/Actors.rxdata")
    $data_classes       = load_data("Data/Classes.rxdata")
    $data_skills        = load_data("Data/Skills.rxdata")
    $data_items         = load_data("Data/Items.rxdata")
    $data_weapons       = load_data("Data/Weapons.rxdata")
    $data_armors        = load_data("Data/Armors.rxdata")
    $data_enemies       = load_data("Data/Enemies.rxdata")
    $data_troops        = load_data("Data/Troops.rxdata")
    $data_states        = load_data("Data/States.rxdata")
    $data_animations    = load_data("Data/Animations.rxdata")
    $data_tilesets      = load_data("Data/Tilesets.rxdata")
    $data_common_events = load_data("Data/CommonEvents.rxdata")
    $data_system        = load_data("Data/System.rxdata")
    # j[pOvpeB
    Properties_Interface_Module.load_properties($data_items,'id','Data/MenuLogItems.rxdata')
    Properties_Interface_Module.load_properties($data_skills,'id','Data/MenuLogSkills.rxdata')
    # 퓬pANVOvpeB
    Properties_Interface_Module.load_properties($data_states,'id','Data/ActionLogStates.rxdata')
    Properties_Interface_Module.load_properties($data_skills,'id','Data/ActionLogSkills.rxdata')
    Properties_Interface_Module.load_properties($data_items,'id','Data/ActionLogItems.rxdata')
    # VXeIuWFNg쐬
    $game_system = Game_System.new
    # ^CgOtBbN쐬
    @sprite = Sprite.new
    @sprite.bitmap = RPG::Cache.title($data_system.title_name)
    # ^Cg BGM t
    $game_system.bgm_play($data_system.title_bgm)
    # MEABGS ̉t~
    Audio.me_stop
    Audio.bgs_stop
    # gWVs
    Graphics.transition(8)
    # C[v
    loop do
      # Q[ʂXV
      Graphics.update
      # ͏XV
      Input.update
      # t[XV
      update
      # ʂ؂ւ烋[v𒆒f
      if $scene != self
        break
      end
    end
    # gWV
    Graphics.freeze
    # ^CgOtBbN
    @sprite.bitmap.dispose
    @sprite.dispose
  end
  #--------------------------------------------------------------------------
  #  t[XV
  #--------------------------------------------------------------------------
  def update
    # C {^ꂽꍇ
    if Input.trigger?(Input::C)
      $scene = DQ::Scene_Title.new
    end
  end
end
